@@ -16,7 +16,7 @@ use IPC::Cmd               qw(run can_run);
 use Readonly               qw(Readonly);
 use English                qw(-no_match_vars);
 
-use version; our $VERSION = qv('0.03');
+our $VERSION = '0.04';
 
 ####
 #### CLASS CONSTANTS
@@ -33,8 +33,8 @@ configuration.
 END_MSG
 
 
-# Override a package's name if to conform to packaging guidelines.
-# Copied from CPANPLUS::Dist::Pacman.
+# Override a package's name to conform to packaging guidelines.
+# Copied entries from CPANPLUS::Dist::Pacman.
 Readonly my $PKGNAME_OVERRIDES =>
 { map { split /[\s=]+/ } split /\s*\n+\s*/, <<'END_OVERRIDES' };
 
@@ -86,8 +86,8 @@ build() {
   ( cd "${srcdir}/[% distdir %]"
     perl Makefile.PL INSTALLDIRS=vendor &&
     make &&
-[% skiptest_comment %] PERL_MM_USE_DEFAULT=1 make test &&
-     make DESTDIR="${pkgdir}/" install
+[% skiptest_comment %]   PERL_MM_USE_DEFAULT=1 make test &&
+    make DESTDIR="${pkgdir}/" install
   ) || return 1;
 [% FI %]
 [% IF is_modulebuild %]
@@ -114,9 +114,9 @@ $PACKAGER = 'Anonymous';
 
 READ_CONF:
 {
-	# Read makepkg.conf to see if there are system-wide settings
+    # Read makepkg.conf to see if there are system-wide settings
     my $mkpkgconf;
-	if ( ! open $mkpkgconf, '<', $MKPKGCONF_FQP ) {
+    if ( ! open $mkpkgconf, '<', $MKPKGCONF_FQP ) {
         error "Could not read $MKPKGCONF_FQP: $!";
         last READ_CONF;
     }
@@ -126,12 +126,12 @@ READ_CONF:
 
     my $cfg_var_match = '(' . join( '|', keys %cfg_vars ) . ')';
 
-	while (<$mkpkgconf>) {
+    while (<$mkpkgconf>) {
         if (/ ^ $cfg_var_match = "? (.*?) "? $ /xmso) {
             ${$cfg_vars{$1}} = $2;
         }
-	}
-	close $mkpkgconf or error "close on makepkg.conf: $!";
+    }
+    close $mkpkgconf or error "close on makepkg.conf: $!";
 }
 
 ####
@@ -140,151 +140,151 @@ READ_CONF:
 
 sub format_available
 {
-	for my $prog ( qw/ makepkg pacman / ) {
-		if ( ! can_run($prog) ) {
-			error "CPANPLUS::Dist::Arch needs to run $prog, to work properly";
-			return 0;
-		}
-	}
-	return 1;
+    for my $prog ( qw/ makepkg pacman / ) {
+        if ( ! can_run($prog) ) {
+            error "CPANPLUS::Dist::Arch needs to run $prog, to work properly";
+            return 0;
+        }
+    }
+    return 1;
 }
 
 sub init
 {
-	my $self = shift;
+    my $self = shift;
 
-	$self->status->mk_accessors( qw{ pkgname  pkgver  pkgbase pkgdesc
+    $self->status->mk_accessors( qw{ pkgname  pkgver  pkgbase pkgdesc
                                      pkgurl   pkgsize pkgarch
                                      builddir destdir } );
-	return 1;
+    return 1;
 }
 
 sub prepare
 {
-	my ($self, %opts) = (shift, @_);
+    my ($self, %opts) = (shift, @_);
 
-	my $status   = $self->status;				 # Private hash
-	my $module   = $self->parent;				 # CPANPLUS::Module
-	my $intern   = $module->parent;				 # CPANPLUS::Internals
-	my $conf     = $intern->configure_object;	 # CPANPLUS::Configure
-	my $distcpan = $module->status->dist_cpan;	 # CPANPLUS::Dist::MM or
-	                                             # CPANPLUS::Dist::Build
+    my $status   = $self->status;                # Private hash
+    my $module   = $self->parent;                # CPANPLUS::Module
+    my $intern   = $module->parent;              # CPANPLUS::Internals
+    my $conf     = $intern->configure_object;    # CPANPLUS::Configure
+    my $distcpan = $module->status->dist_cpan;   # CPANPLUS::Dist::MM or
+                                                 # CPANPLUS::Dist::Build
 
-	$self->_prepare_status;
+    $self->_prepare_status;
 
     $status->prepared(0);
 
-	# Create a directory for the new package
-	for my $dir ( $status->pkgbase, $status->destdir ) {
-		if ( -e $dir ) {
-			die "$dir exists but is not a directory!" if ( ! -d _ );
-			die "$dir exists but is read-only!"       if ( ! -w _ );
-		}
+    # Create a directory for the new package
+    for my $dir ( $status->pkgbase, $status->destdir ) {
+        if ( -e $dir ) {
+            die "$dir exists but is not a directory!" if ( ! -d _ );
+            die "$dir exists but is read-only!"       if ( ! -w _ );
+        }
         else {
             mkpath $dir
                 or die qq{failed to create directory '$dir': $OS_ERROR};
             if ( $opts{verbose} ) { msg "Created directory $dir" }
         }
-	}
+    }
 
-	return $self->SUPER::prepare(@_);
+    return $self->SUPER::prepare(@_);
 }
 
 sub create
 {
-	my ($self, %opts) = (shift, @_);
+    my ($self, %opts) = (shift, @_);
 
-	my $status   = $self->status;				 # Private hash
-	my $module   = $self->parent;				 # CPANPLUS::Module
-	my $intern   = $module->parent;				 # CPANPLUS::Internals
-	my $conf     = $intern->configure_object;	 # CPANPLUS::Configure
-	my $distcpan = $module->status->dist_cpan;	 # CPANPLUS::Dist::MM or
-	                                             # CPANPLUS::Dist::Build
+    my $status   = $self->status;                # Private hash
+    my $module   = $self->parent;                # CPANPLUS::Module
+    my $intern   = $module->parent;              # CPANPLUS::Internals
+    my $conf     = $intern->configure_object;    # CPANPLUS::Configure
+    my $distcpan = $module->status->dist_cpan;   # CPANPLUS::Dist::MM or
+                                                 # CPANPLUS::Dist::Build
 
     # Use CPANPLUS::Dist::Base to make packages for pre-requisites...
 
-	my @ok_resolve_args = qw/ verbose target force prereq_build /;
+    my @ok_resolve_args = qw/ verbose target force prereq_build /;
     my %resolve_args = map { exists $opts{$_}  ?
                              ($_ => $opts{$_}) : () } @ok_resolve_args;
 
-	$distcpan->_resolve_prereqs( %resolve_args,
-				    			 'format'  => ref $self,
+    $distcpan->_resolve_prereqs( %resolve_args,
+                                 'format'  => ref $self,
                                  'prereqs' => $module->status->prereqs );
 
     # Prepare our file name paths for pkgfile and source tarball...
- 	my $pkgfile = join '-', ("${\$status->pkgname}",
+    my $pkgfile = join '-', ("${\$status->pkgname}",
                              "${\$status->pkgver}-1",
                              "${\$status->pkgarch}.pkg.tar.gz");
 
-	my $srcfile_fqp = $status->pkgbase . '/' . $module->package;
-	my $pkgfile_fqp = $status->pkgbase . "/$pkgfile";
+    my $srcfile_fqp = $status->pkgbase . '/' . $module->package;
+    my $pkgfile_fqp = $status->pkgbase . "/$pkgfile";
 
     # Prepare our 'makepkg' package building directory,
     # namely the PKGBUILD and source tarball files...
-	if ( ! -e $srcfile_fqp ) {
+    if ( ! -e $srcfile_fqp ) {
         my $tarball_fqp = $module->_status->fetch;
         link $tarball_fqp, $srcfile_fqp
             or error "Failed to create link to $tarball_fqp: $OS_ERROR";
-	}
+    }
 
-	$self->_create_pkgbuild( skiptest => $opts{skiptest} );
+    $self->_create_pkgbuild( skiptest => $opts{skiptest} );
 
     # Starting your engines!
-	chdir $status->pkgbase or die "chdir: $OS_ERROR";
-	my $makepkg_cmd = join ' ', ( 'makepkg',
+    chdir $status->pkgbase or die "chdir: $OS_ERROR";
+    my $makepkg_cmd = join ' ', ( 'makepkg',
                                   #'-m',
                                   ( $opts{force}    ? '-f'         : () ),
                                   ( !$opts{verbose} ? '>/dev/null' : () )
                                  );
-	system $makepkg_cmd;
+    system $makepkg_cmd;
 
-	if ($?) {
+    if ($?) {
         error ( $? & 127
                 ? sprintf "makepkg failed with signal %d\n",        $? & 127
                 : sprintf "makepkg returned abnormal status: %d\n", $? >> 8 );
-		return 0;
-	}
+        return 0;
+    }
 
     my $destfile_fqp = catfile( $status->destdir, $pkgfile );
-	if ( ! rename $pkgfile_fqp, $destfile_fqp ) {
-		error "failed to move $pkgfile to $destfile_fqp: $OS_ERROR";
-		return 0;
-	}
+    if ( ! rename $pkgfile_fqp, $destfile_fqp ) {
+        error "failed to move $pkgfile to $destfile_fqp: $OS_ERROR";
+        return 0;
+    }
 
-	$status->dist($destfile_fqp);
+    $status->dist($destfile_fqp);
     return $status->created(1);
 }
 
 sub install
 {
-	my ($self, %opts) = (shift, @_);
+    my ($self, %opts) = (shift, @_);
 
-	my $status   = $self->status;			  # Private hash
-	my $module   = $self->parent;			  # CPANPLUS::Module
-	my $intern   = $module->parent;			  # CPANPLUS::Internals
-	my $conf     = $intern->configure_object; # CPANPLUS::Configure
+    my $status   = $self->status;             # Private hash
+    my $module   = $self->parent;             # CPANPLUS::Module
+    my $intern   = $module->parent;           # CPANPLUS::Internals
+    my $conf     = $intern->configure_object; # CPANPLUS::Configure
 
-	my $sudocmd = $conf->get_program('sudo');
-	if( $EFFECTIVE_USER_ID != $ROOT_USER_ID ) {
-		if( $sudocmd ) {
+    my $sudocmd = $conf->get_program('sudo');
+    if( $EFFECTIVE_USER_ID != $ROOT_USER_ID ) {
+        if( $sudocmd ) {
             system "sudo pacman -U ${\$status->dist}";
         }
-		else {
-			error $NONROOT_WARNING;
-			return 0;
-		}
-	}
-	else { system "pacman -U ${\$status->dist}"; }
+        else {
+            error $NONROOT_WARNING;
+            return 0;
+        }
+    }
+    else { system "pacman -U ${\$status->dist}"; }
 
-	if ($?) {
+    if ($?) {
         error ( $? & 127
                 ? sprintf "pacman failed with signal %d",        $? & 127
                 : sprintf "pacman returned abnormal status: %d", $?>>8   
                );
-		return 0;
-	}
+        return 0;
+    }
 
-	return $status->installed(1);
+    return $status->installed(1);
 }
 
 
@@ -293,22 +293,18 @@ sub install
 ####
 
 #---INSTANCE METHOD---
-# Usage   : my $pkgname = $self->_translate_pkgname($module_object);
+# Usage   : my $pkgname = $self->_translate_pkgname($dist_name);
 # Purpose : Converts a module's dist[ribution tarball] name to an
 #           Archlinux style perl package name.
-# Params  : $nodule_object - A CPANPLUS::Module object.
+# Params  : $dist_name - The name of the distribution (ex: Acme-Drunk)
 # Returns : The Archlinux perl package name (ex: perl-acme-drunk).
 #---------------------
-
 sub _translate_name
 {
-    my ($self, $module) = @_;
-
-    my $distext  = $module->package_extension;
-    my $distname = $module->package;
-
-    $distname =~ s/ - [\d.]+ [.] $distext \z //oxms;
+    die "Invalid arguments to _translate_name method" if @_ != 2;
+    my ($self, $distname) = @_;
 
+    # Override this package name if there is one specified...
     return $PKGNAME_OVERRIDES->{$distname}
         if $PKGNAME_OVERRIDES->{$distname};
 
@@ -320,36 +316,49 @@ sub _translate_name
     return $distname;
 }
 
+#---INSTANCE METHOD---
+# Purpose  : Convert CPAN a module's distribution version into our more
+#            restrictive pacman package version number.
+#---------------------
+sub _translate_version
+{
+    die "Invalid arguments to _translate_version method" if @_ != 2;
+    my ($self, $version) = @_;
+
+    # Remove anything other than numbers and decimal points.
+    $version =~ tr/0-9.//c;
+    return $version;
+}
+
 #---INSTANCE METHOD---
 # Usage    : my $deps_str = $self->_translate_cpan_deps()
 # Purpose  : Convert CPAN prerequisites into pacman package dependencies
 # Returns  : String to be appended after 'depends=' in PKGBUILD file,
 #            without parenthesis.
 #---------------------
-
 sub _translate_cpan_deps
 {
     my ($self) = @_;
 
-	my %pkgdeps;
+    my %pkgdeps;
 
     my $module  = $self->parent;
     my $backend = $module->parent;
-	my $prereqs = $module->status->prereqs;
+    my $prereqs = $module->status->prereqs;
 
     CPAN_DEP_LOOP:
-	for my $modname (keys %{$prereqs}) {
+    for my $modname (keys %{$prereqs}) {
         my $depver = $prereqs->{$modname};
 
-		# Sometimes a perl version is given as a prerequisite
-		# XXX Seems filtered out of prereqs() hash beforehand..?
-		if ( $modname eq 'perl' ) {
+        # Sometimes a perl version is given as a prerequisite
+        # XXX Seems filtered out of prereqs() hash beforehand..?
+        if ( $modname eq 'perl' ) {
             $pkgdeps{perl} = $depver;
-			next CPAN_DEP_LOOP;
-		}
+            next CPAN_DEP_LOOP;
+        }
 
         # Ignore modules included with this version of perl...
-		next CPAN_DEP_LOOP
+        next CPAN_DEP_LOOP
             if ( exists $Module::CoreList::version{0+$]}->{$modname} );
 
         # Use a module's _distribution_ name (tarball filename) instead
@@ -357,16 +366,16 @@ sub _translate_cpan_deps
         # pacman package file...
 
         my $modobj  = $backend->parse_module( module => $modname );
-        my $pkgname = $self->_translate_name($modobj);
+        my $pkgname = $self->_translate_name( $modobj->package_name );
 
-        $pkgdeps{$pkgname} = $depver;
-	}
+        $pkgdeps{$pkgname} = $self->_translate_version($depver);
+    }
 
     # Default to requiring the current perl version used to compile
     # the module if there is no explicit perl version required...
     $pkgdeps{perl} ||= sprintf '%vd', $PERL_VERSION;
 
-	return ( join ' ',
+    return ( join ' ',
              map { $pkgdeps{$_} ? qq{'${_}>=$pkgdeps{$_}'} : qq{'$_'} }
              sort keys %pkgdeps );
 }
@@ -380,18 +389,16 @@ sub _translate_cpan_deps
 # Returns  : The package short description.
 # Comments : We search through the META.yml file and then the README file.
 #---------------------
-
 #TODO# This should also look in the module source code's POD.
-
 sub _prepare_pkgdesc
 {
-	my ($self) = @_;
-	my ($status, $module, $pkgdesc) = ($self->status, $self->parent);
+    my ($self) = @_;
+    my ($status, $module, $pkgdesc) = ($self->status, $self->parent);
 
     return $status->pkgdesc( $module->description )
         if ( $module->description );
 
-	# First, try to find the short description in the META.yml file.
+    # First, try to find the short description in the META.yml file.
     METAYML:
     {
         my $metayml;
@@ -411,23 +418,23 @@ sub _prepare_pkgdesc
         close $metayml;
     }
 
-	# Next, try to find it in in the README file
-	open my $readme, '<', $module->status->extract . '/README'
+    # Next, try to find it in in the README file
+    open my $readme, '<', $module->status->extract . '/README'
         or return $status->pkgdesc(q{});
-#	error( "Could not open README to get pkgdesc: $!" ), return undef;
+#   error( "Could not open README to get pkgdesc: $!" ), return undef;
 
-	my $modname = $module->name;
-	while ( <$readme> ) {
+    my $modname = $module->name;
+    while ( <$readme> ) {
         chomp;
-		if ( (/^NAME/ ... /^[A-Z]+/) &&
+        if ( (/^NAME/ ... /^[A-Z]+/) &&
              (($pkgdesc) = / ^ \s* ${modname} [\s\-]+ (.+) $ /oxms) ) {
             close $readme;
             return $status->pkgdesc($pkgdesc);
-		}
-	}
-	close $readme;
+        }
+    }
+    close $readme;
 
-	return $status->pkgdesc(q{});
+    return $status->pkgdesc(q{});
 }
 
 #---INSTANCE METHOD---
@@ -437,12 +444,11 @@ sub _prepare_pkgdesc
 # Postcond : Accessors assigned to: pkgname pkgver pkgbase pkgarch
 # Returns  : The object's status accessor.
 #---------------------
-
 sub _prepare_status
 {
-	my $self     = shift;
-	my $status   = $self->status; # Private hash
-	my $module   = $self->parent; # CPANPLUS::Module
+    my $self     = shift;
+    my $status   = $self->status; # Private hash
+    my $module   = $self->parent; # CPANPLUS::Module
     my $conf     = $module->parent->configure_object;
 
     my $our_base = catdir( $conf->get_conf('base'),
@@ -451,25 +457,26 @@ sub _prepare_status
 
     $status->destdir( $PKGDEST || catdir( $our_base, 'pkg' ) );
 
-	my ($pkgver, $pkgname) = ( $module->version,
-                               $self->_translate_name($module) );
+    my ($pkgver, $pkgname)
+        = ( $self->_translate_version($module->package_version),
+            $self->_translate_name($module->package_name) );
 
-	my $pkgbase = catdir( $our_base, 'build', $pkgname );
-	my $pkgarch = `uname -m`;
-	chomp $pkgarch;
+    my $pkgbase = catdir( $our_base, 'build', "$pkgname-$pkgver" );
+    my $pkgarch = `uname -m`;
+    chomp $pkgarch;
 
-	foreach ( $pkgname, $pkgver, $pkgbase, $pkgarch ) {
-		die "A package variable is invalid" unless defined;
-	}
+    foreach ( $pkgname, $pkgver, $pkgbase, $pkgarch ) {
+        die "A package variable is invalid" unless defined;
+    }
 
-	$status->pkgname($pkgname);
-	$status->pkgver ($pkgver );
-	$status->pkgbase($pkgbase);
-	$status->pkgarch($pkgarch);
+    $status->pkgname($pkgname);
+    $status->pkgver ($pkgver );
+    $status->pkgbase($pkgbase);
+    $status->pkgarch($pkgarch);
 
-	$self->_prepare_pkgdesc();
+    $self->_prepare_pkgdesc();
 
-	return $status;
+    return $status;
 }
 
 #---INSTANCE METHOD---
@@ -477,15 +484,14 @@ sub _prepare_status
 # Purpose  : Creates a nice, version agnostic homepage URL for the distribution.
 # Returns  : URL to the distribution's web page on CPAN.
 #---------------------
-
 sub _get_disturl
 {
-	my $self   = shift;
-	my $module = $self->parent;
+    my $self   = shift;
+    my $module = $self->parent;
 
-	my $distname  = $module->name;
-	$distname     =~ tr/:/-/s;
-	return join '/', $CPANURL, 'dist', $distname;
+    my $distname  = $module->name;
+    $distname     =~ tr/:/-/s;
+    return join '/', $CPANURL, 'dist', $distname;
 }
 
 #---INSTANCE METHOD---
@@ -493,13 +499,12 @@ sub _get_disturl
 # Purpose  : Generates the standard cpan download link for the source tarball.
 # Returns  : URL to the distribution's tarball on CPAN.
 #---------------------
-
 sub _get_srcurl
 {
-	my ($self) = @_;
-	my $module = $self->parent;
+    my ($self) = @_;
+    my $module = $self->parent;
 
-	return join '/', $CPANURL, $module->path, $module->package;
+    return join '/', $CPANURL, $module->path, $module->package;
 }
 
 #---INSTANCE METHOD---
@@ -509,7 +514,6 @@ sub _get_srcurl
 # Throws   : failed to get md5 of <filename>: ...
 # Returns  : The MD5 sum of the .tar.gz file in hex string form.
 #---------------------
-
 sub _calc_tarballmd5
 {
     my ($self) = @_;
@@ -536,25 +540,24 @@ sub _calc_tarballmd5
 #            failed to write PKGBUILD: ...
 # Returns  : Nothing.
 #---------------------
-
 sub _create_pkgbuild
 {
-	my $self = shift;
-	my %opts = @_;
+    my $self = shift;
+    my %opts = @_;
 
-	my $status  = $self->status;
+    my $status  = $self->status;
     my $module  = $self->parent;
-	my $conf    = $module->parent->configure_object;
+    my $conf    = $module->parent->configure_object;
 
     my $pkgdeps = $self->_translate_cpan_deps;
 
-	my $pkgdesc = $status->pkgdesc;
-	my $fqpath  = catfile( $status->pkgbase, 'PKGBUILD' );
+    my $pkgdesc = $status->pkgdesc;
+    my $fqpath  = catfile( $status->pkgbase, 'PKGBUILD' );
 
-	my $extdir  = $module->package;
-    $extdir     =~ s/ [.] ${\$module->package_extension} $ //xms;
+    my $extdir  = $module->package;
+    $extdir     =~ s/ [.] ${\$module->package_extension} \z //xms;
 
-	$pkgdesc    =~ s/ " / \\" /gxms; # Quote our package desc for bash.
+    $pkgdesc    =~ s/ " / \\" /gxms; # Quote our package desc for bash.
 
     my $templ_vars = { packager  => $PACKAGER,
                        version   => $VERSION,
@@ -574,7 +577,7 @@ sub _create_pkgbuild
                                              ? '#' : ' ' )
                       };
 
-	my $dist_type = $module->status->installer_type;
+    my $dist_type = $module->status->installer_type;
     @{$templ_vars}{'is_makemaker', 'is_modulebuild'} =
         ( $dist_type eq 'CPANPLUS::Dist::MM'    ? (1, 0) :
           $dist_type eq 'CPANPLUS::Dist::Build' ? (0, 1) :
@@ -583,13 +586,13 @@ sub _create_pkgbuild
     my $pkgbuild_text = $self->_process_template( $PKGBUILD_TEMPL,
                                                   $templ_vars );
 
-	open my $pkgbuild_file, '>', $fqpath
+    open my $pkgbuild_file, '>', $fqpath
         or die "failed to write PKGBUILD: $OS_ERROR";
     print $pkgbuild_file $pkgbuild_text;
-	close $pkgbuild_file
+    close $pkgbuild_file
         or die "failed to write PKGBUILD: $OS_ERROR";
 
-	return;
+    return;
 }
 
 #---INSTANCE METHOD---
@@ -603,7 +606,6 @@ sub _create_pkgbuild
 #            it is undefined.
 # Returns  : String of the template with all variables filled inserted.
 #---------------------
-
 sub _process_template
 {
     die "Invalid arguments to _template_out" if @_ != 3;
